waveformtools.compare — waveformtools 2022-05-03 documentation

# waveformtools.compare

Compare the waveforms and modes

Functions

`plot_mode_differences`(waveforms[, nmodes, ...]) | Plot the fractional difference of the first nmodes dominant modes of the input waveforms.
`plot_modes`(wf1[, nmodes, save_fig, xlim, ...]) | Plot the first nmodes dominant modes of the input waveforms

waveformtools.compare.plot_mode_differences(waveforms, nmodes=3, save_fig=False, xlabel='t/M', ylabel='r\\Psi_{4}^{(\\ell m)}', labels=None, xlim=[- 1000, 100])

  Plot the fractional difference of the first nmodes dominant modes of the input waveforms.

  Parameters:
    waveforms: modes_array

      The list of modes_array waveforms to plot.

    nmodes: int

      The number of modes to plot.

    tol: float

      The tolerance to detect the modes.

  Returns:
    Plots.

waveformtools.compare.plot_modes(wf1, nmodes=3, save_fig=False, xlim=[- 1200, 100], ylim='auto', nstop=1, plot22=False)

  Plot the first nmodes dominant modes of the input waveforms

  Parameters:
    wf: modes_array

      The list of modes_array waveforms to plot.

    nmodes: int

      The number of modes to plot.

    tol: float

      The tolerance to detect the modes.

  Returns:
    Plots.